@@ -33,7 +33,6 @@ def job_parser(parser, group=None):
     """Parser settings for every action doing builds."""
     group.add_argument("-j", dest="num_jobs", type=int,
         help="Number of jobs to use")
-    parser.set_defaults(num_jobs=1)
 
 def build_parser(parser):
     """Parser settings for every action doing build.
@@ -50,7 +49,9 @@ def build_parser(parser):
         help="The configuration to use. "
              "It should be the name of a toolchain, or \"system\"")
     group.add_argument("-p", "--profile", dest="profiles", action="append",
+        metavar="PROFILE",
         help="A profile to use. "
+             "It can appear several times. "
              "It should match a declaration in .qi/qibuild.xml")
 
 def project_parser(parser, positional=True):
@@ -60,30 +61,36 @@ def project_parser(parser, positional=True):
     # NOT solve the deps by default (for instance for `qibuild test`)
     group.add_argument("--use-deps", action="store_true", dest="use_deps",
                        help="Force deps resolution")
-    group.add_argument("--build-deps-only", action="store_true",
-                       dest="build_only",
+    group.add_argument("--build-deps-only", action="store_const",
+                       const=["build"], dest="dep_types",
                        help="Work on specified projects by ignoring "
                              "the runtime deps.")
-    parser.set_defaults(build_only=False)
+    parser.set_defaults(dep_types="default")
 
-def get_build_worktree(args):
+def get_build_worktree(args, verbose=True):
     """ Get a build worktree to use from a argparse.Namespace
     object
 
     """
     worktree = qisys.parsers.get_worktree(args)
     build_worktree = qibuild.worktree.BuildWorkTree(worktree)
-    ui.info(ui.green, "Current build worktree:", ui.reset, ui.bold, build_worktree.root)
+    if verbose:
+        ui.info(ui.green, "Current build worktree:", ui.reset, ui.bold, build_worktree.root)
     if not hasattr(args, "build_type"):
         # build_parser() has not been called, so do leave the default build_config
         return build_worktree
     build_config = get_build_config(build_worktree, args)
     build_worktree.build_config = build_config
-    if build_config.toolchain:
-        ui.info(ui.green, "Using toolchain:", ui.blue, build_config.toolchain.name)
-    for profile in build_config.profiles:
-        ui.info(ui.green, "Using profile:", ui.blue, profile)
-    ui.info(ui.green, "Build type:", ui.blue, build_config.build_type)
+
+    if verbose:
+        if build_config.toolchain:
+            ui.info(ui.green, "Using toolchain:", ui.blue, build_config.toolchain.name)
+
+        for profile in build_config.profiles:
+            ui.info(ui.green, "Using profile:", ui.blue, profile)
+
+        ui.info(ui.green, "Build type:", ui.blue, build_config.build_type)
+
     return build_worktree
 
 def get_build_projects(build_worktree, args, solve_deps=True, default_all=False):
@@ -96,10 +103,7 @@ def get_build_projects(build_worktree, args, solve_deps=True, default_all=False)
     projects = parser.parse_args(args, default_all=default_all)
     if not solve_deps or args.single:
         return projects
-    if args.build_only:
-        dep_types = ["build"]
-    else:
-        dep_types = ["build", "runtime"]
+    dep_types = get_dep_types(args)
     deps_solver = qibuild.deps_solver.DepsSolver(build_worktree)
     return deps_solver.get_dep_projects(projects, dep_types)
 
@@ -114,17 +118,17 @@ def get_one_build_project(build_worktree, args):
         raise Exception("This action can only work on one project")
     return projects[0]
 
-def get_dep_types(args):
+def get_dep_types(args, default=None):
     """ Get a list of dep types from the command line """
+    if not default:
+        default = ["build", "runtime", "test"]
     if args.single:
         return list()
-    if hasattr(args, "runtime_only") and args.runtime_only:
-        return ["runtime"]
-    if hasattr(args, "build_only") and args.build_only:
-        return ["build"]
-    return ["build", "runtime"]
+    if not hasattr(args, "dep_types") or args.dep_types == "default":
+        return default
+    return args.dep_types
 
-def get_cmake_builder(args):
+def get_cmake_builder(args, default_dep_types=None):
     """ Get a :py:class:`.CMakeBuilder` object from the command line
 
     """
@@ -132,7 +136,7 @@ def get_cmake_builder(args):
     # dep solving will be made later by the CMakeBuilder
     build_projects = get_build_projects(build_worktree, args, solve_deps=False)
     cmake_builder = qibuild.cmake_builder.CMakeBuilder(build_worktree, build_projects)
-    cmake_builder.dep_types = get_dep_types(args)
+    cmake_builder.dep_types = get_dep_types(args, default=default_dep_types)
     return cmake_builder
 
 ##
@@ -178,6 +182,7 @@ class BuildProjectParser(qisys.parsers.AbstractProjectParser):
         mathes the current directory
 
         """
+        # step 1: find the closest buildable project
         parser = qisys.parsers.WorkTreeProjectParser(self.build_worktree.worktree)
         worktree_projects = parser.parse_no_project(args)
         if not worktree_projects:
@@ -185,9 +190,15 @@ class BuildProjectParser(qisys.parsers.AbstractProjectParser):
 
         # WorkTreeProjectParser returns None or a list of one element
         worktree_proj = worktree_projects[0]
-        build_proj = qibuild.worktree.new_build_project(self.build_worktree,
-                                                        worktree_proj)
+        build_proj = qisys.parsers.find_parent_project(self.build_worktree.build_projects,
+                                                       worktree_proj.path)
         if not build_proj:
+            # step 2: if we can't find, still look for a qiproject.xml not
+            # registered yet and add it to the worktree:
+            build_proj = qibuild.worktree.new_build_project(self.build_worktree,
+                                                            worktree_proj)
+        if not build_proj:
+            # give up:
             raise CouldNotGuessProjectName()
 
         return self.parse_one_project(args, build_proj.name)
