@@ -21,8 +21,9 @@ class BuildProject(object):
         self.src = worktree_project.src
         self.name = None
         # depends is a set at this point because they are not sorted yet
-        self.depends = set()
-        self.rdepends = set()
+        self.build_depends = set()
+        self.run_depends = set()
+        self.test_depends = set()
 
     @property
     def qiproject_xml(self):
@@ -31,8 +32,7 @@ class BuildProject(object):
 
     @property
     def cmake_qibuild_dir(self):
-        worktree = self.build_worktree.worktree
-        return qibuild.cmake.get_cmake_qibuild_dir(worktree=worktree)
+        return qibuild.cmake.get_cmake_qibuild_dir()
 
     @property
     def build_directory(self):
@@ -105,7 +105,7 @@ class BuildProject(object):
     def write_qi_path_conf(self, sdk_dirs):
         """ Write the <build>/sdk/share/qi/path.conf file. This file
         can be used for instance by qi::path::find() functions, to
-        finf files from the dependencies' build directory
+        find files from the dependencies' build directory
 
         """
         to_write = "# File autogenerated by qibuild configure based on\n"
@@ -179,13 +179,21 @@ set(CMAKE_FIND_ROOT_PATH ${{CMAKE_FIND_ROOT_PATH}} CACHE INTERNAL ""  FORCE)
             custom_cmake_code=custom_cmake_code
         )
 
+        import qibuild
+        qibuild_python = os.path.join(qibuild.__file__, "..", "..")
+        qibuild_python = os.path.abspath(qibuild_python)
+        qibuild_python = qisys.sh.to_posix_path(qibuild_python)
+        to_write += """
+set(QIBUILD_PYTHON_PATH "%s" CACHE STRING "" FORCE)
+""" % qibuild_python
+
+
         qisys.sh.mkdir(self.build_directory, recursive=True)
         dep_cmake = os.path.join(self.build_directory, "dependencies.cmake")
         qisys.sh.write_file_if_different(to_write, dep_cmake)
 
     def configure(self, **kwargs):
         """ Delegate to :py:func:`qibuild.cmake.cmake` """
-        # FIXME: done by write_dependencies_cmake
         qisys.sh.mkdir(self.build_directory, recursive=True)
         cmake_args = self.cmake_args
         # only required the first time, afterwards this setting is
@@ -226,7 +234,6 @@ set(CMAKE_FIND_ROOT_PATH ${{CMAKE_FIND_ROOT_PATH}} CACHE INTERNAL ""  FORCE)
         cmd += [ "--" ]
         cmd += self.parse_num_jobs(self.build_config.num_jobs)
 
-
         if not env:
             build_env = self.build_env.copy()
         else:
@@ -248,7 +255,7 @@ set(CMAKE_FIND_ROOT_PATH ${{CMAKE_FIND_ROOT_PATH}} CACHE INTERNAL ""  FORCE)
         if not cmake_generator:
             cmake_generator = \
                     qibuild.cmake.get_cached_var(self.build_directory, "CMAKE_GENERATOR")
-        if num_jobs == 1:
+        if num_jobs is None:
             return list()
         if "Unix Makefiles" in cmake_generator or \
             "Ninja" in cmake_generator:
@@ -267,7 +274,7 @@ set(CMAKE_FIND_ROOT_PATH ${{CMAKE_FIND_ROOT_PATH}} CACHE INTERNAL ""  FORCE)
         return list()
 
 
-    def install(self, destdir, prefix="/", runtime=False, num_jobs=1,
+    def install(self, destdir, prefix="/", components=None, num_jobs=1,
                 split_debug=False):
         """ Install the project
 
@@ -304,46 +311,40 @@ set(CMAKE_FIND_ROOT_PATH ${{CMAKE_FIND_ROOT_PATH}} CACHE INTERNAL ""  FORCE)
             mess += "CMAKE_INSTALL_PREFIX is already correct"
             ui.debug(mess)
 
-        if runtime:
-            self.install_runtime(destdir)
+        # Hack for http://www.cmake.org/Bug/print_bug_page.php?bug_id=13934
+        if self.using_make:
+            self.build(target="preinstall", num_jobs=num_jobs, env=build_env)
+        if components:
+            for component in components:
+                self._install_component(destdir, component)
         else:
             self.build(target="install", env=build_env)
 
         if split_debug:
             self.split_debug(destdir)
 
-    def install_runtime(self, destdir):
+    def _install_component(self, destdir, component):
         build_env = self.build_env.copy()
         build_env["DESTDIR"] = destdir
 
-        num_jobs = self.parse_num_jobs(self.build_config.num_jobs)
-        # Hack for http://www.cmake.org/Bug/print_bug_page.php?bug_id=13934
-        if self.using_make:
-            self.build(target="preinstall", num_jobs=num_jobs, env=build_env)
+        cmake_args = list()
+        cmake_args += ["-DBUILD_TYPE=%s" % self.build_config.build_type]
+        cmake_args += ["-DCOMPONENT=%s" % component]
+        cmake_args += ["-P", "cmake_install.cmake", "--"]
+        ui.debug("Installing", component)
+        qisys.command.call(["cmake"] + cmake_args, cwd=self.build_directory,
+                            env=build_env)
 
-        runtime_components = [
-             "binary",
-             "data",
-             "conf",
-             "lib",
-             "python",
-             "doc"
-         ]
-        for component in runtime_components:
-            cmake_args = list()
-            cmake_args += ["-DBUILD_TYPE=%s" % self.build_config.build_type]
-            cmake_args += ["-DCOMPONENT=%s" % component]
-            cmake_args += ["-P", "cmake_install.cmake", "--"]
-            ui.debug("Installing", component)
-            qisys.command.call(["cmake"] + cmake_args, cwd=self.build_directory,
-                               env=build_env)
-
-    def deploy(self, url, split_debug=False, use_rsync=True, port=22):
+    def deploy(self, url, port=22, split_debug=False,
+               use_rsync=True, with_tests=True):
         """ Deploy the project to a remote url """
         destdir = os.path.join(self.build_directory, "deploy")
         #create folder for project without install rules
         qisys.sh.mkdir(destdir, recursive=True)
-        self.install_runtime(destdir)
+        components=["runtime"]
+        if with_tests:
+            components.append("test")
+        self.install(destdir, components=components)
         if split_debug:
             self.split_debug(destdir)
         ui.info(ui.green, "Sending binaries to target ...")
